// Copyright (c) 2002 David Muse
// See the COPYING file for more information.

#include <rudiments/private/config.h>

#ifdef RUDIMENTS_HAS_THREADS
	#include <pthread.h>
#endif

#include <netdb.h>
